Welcome to csdmpy’s documentation! — csdmpy 0.1.1 documentation

# Welcome to csdmpy’s documentation!

The csdmpy package is the Python support for the core scientific dataset (CSD) model file exchange-format. The package is based on the core scientific dataset (CSD) model which is designed as a building block in the development of a more sophisticated portable scientific dataset file standard. The CSD model is capable of handling a wide variety of scientific datasets both within and across disciplinary fields.

The main objective of this python package is to facilitate an easy import and export of the CSD model serialized files for Python users. The package utilizes Numpy library and, therefore, offers the end users versatility to process or visualize the imported datasets with any third party package(s) compatible with Numpy.

Table of Contents

- The core scientific dataset (CSD) model
  - CSDM
  - Dimension
  - DependentVariable
  - Enumeration
  - ScalarQuantity
- Installing csdmpy package
- The requirements for csdmpy
- Getting Started With csdmpy package
  - Accessing the dimensions and dependent variables of the dataset
  - Plotting the dataset
- Examples
  - Scalar, 1D{1} datasets
  - Scalar, 2D{1} datasets
  - Vector, 2D{2} datasets
  - Pixel, 2D{3} datasets
  - Correlated Dataset
  - Labeled Dataset
- How to …
  - How to create a new dataset
  - How to add instances of Dimension class
  - How to add instances of DependentVariable class
  - How to save datasets
  - A fun 🤪 example
- API-Reference
  - csdmpy
  - CSDM
  - Dimension
  - DependentVariable

## Indices and tables

- Index

- Module Index

- Search Page